@@ -20,7 +20,6 @@
  * mailto: ninvaders-devel@lists.sourceforge.net
  *
  */
- 
 
 #include "view.h"
 
@@ -28,19 +27,19 @@
 #define UFO
 
 typedef struct Ufo Ufo;
-		
+
 struct Ufo {
-	int posX;	  // horizontal position of aliens
-	int posY;	  // vertical position of aliens
+  int posX; // horizontal position of aliens
+  int posY; // vertical position of aliens
 };
-	
-Ufo ufo;
+
+extern Ufo ufo;
 
 void ufoReset();
 int ufoShowUfo();
 void ufoMoveLeft();
 int ufoHitCheck(int shotX, int shotY);
-	
+
 // methods that handle graphic display, from view.c
 extern void ufoDisplay(int x, int y);
 extern void ufoRefresh();
